/* Copyright 2011 Fredrik Wikstrom. All rights reserved.
**
** Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions
** are met:
**
** 1. Redistributions of source code must retain the above copyright
**    notice, this list of conditions and the following disclaimer.
**
** 2. Redistributions in binary form must reproduce the above copyright
**    notice, this list of conditions and the following disclaimer in the
**    documentation and/or other materials provided with the distribution.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS `AS IS'
** AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
** IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
** ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
** LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
** CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
** SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
** INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
** CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
** ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
** POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef VDITOOL_H
#define VDITOOL_H

#include <exec/exec.h>
#include <dos/dos.h>
#include <proto/exec.h>
#include <proto/dos.h>
#include <proto/utility.h>
#include <string.h>
#include "vdi_format.h"
#include "endian.h"

#define PROGNAME "vditool"

typedef struct {
	CONST_STRPTR filename;
	BPTR file;
	uint32 offset_blocks;
	uint32 offset_data;
	uint32 block_size;
	uint32 total_blocks;
	vdi_header_t *header;
	uint32 *block_map;
} VDIFILE;

typedef struct {
	CONST_STRPTR filename;
	BPTR file;
} RAWFILE;

/* main.c */
extern BPTR StdOut;
extern BPTR StdErr;

/* progress.c */
void display_progress (CONST_STRPTR header, uint32 done, uint32 total);
void stop_progress (void);

/* vdi.c */
VDIFILE *open_vdi (CONST_STRPTR filename, int32 mode);
void close_vdi (VDIFILE *vdi);
BOOL write_header (VDIFILE *vdi);
BOOL read_header (VDIFILE *vdi);
BOOL write_block_map (VDIFILE *vdi);
BOOL read_block_map (VDIFILE *vdi);
BOOL write_block (VDIFILE *vdi, const uint8 *buffer, uint32 block);
BOOL read_block (VDIFILE *vdi, uint8 *buffer, uint32 block);

/* raw.c */
RAWFILE *open_raw (CONST_STRPTR filename, int32 mode);
void close_raw (RAWFILE *raw);

#endif
